@@ -1,4 +1,4 @@
-from . import helpers, security
+from . import app, audit, backup, helpers, security
 from .configs import Config
 
 
@@ -18,5 +18,11 @@ def main(args) -> int:
 
     if args.which == 'security':
         return security.cli_main(args, config)
+    elif args.which == 'audit':
+        return audit.cli_main(args, config)
+    elif args.which == 'backup':
+        return backup.cli_main(args, config)
+    elif args.which == 'app':
+        return app.cli_main(args, config)
 
     return 0
